@@ -18,8 +18,20 @@
 */
 
 #include <stdbool.h>
+#include <pthread.h>
 
-typedef struct
+// Uncomment if you want to synchronize the card movements on the 2
+// interfaces of the Microchip SEC 1210 reader
+// #define SEC1210_SYNC
+
+#ifdef SEC1210_SYNC
+struct _sec1210_cond {
+	pthread_cond_t sec1210_cond;
+	pthread_mutex_t sec1210_mutex;
+};
+#endif
+
+typedef struct _ccid_descriptor
 {
 	/*
 	 * CCID Sequence number
@@ -160,6 +172,12 @@ typedef struct
 	 */
 	bool zlp;
 #endif
+
+#ifdef SEC1210_SYNC
+	struct _sec1210_cond * sec1210_shared;
+	struct _ccid_descriptor *sec1210_other_interface;
+	int sec1210_interface;
+#endif
 } _ccid_descriptor;
 
 /* Features from dwFeatures */
@@ -226,6 +244,7 @@ typedef struct
 #define GEMPCTWIN	0x08E63437
 #define GEMPCPINPAD 0x08E63478
 #define GEMCORESIMPRO 0x08E63480
+#define THALES_FUSION_NFC 0x08E634D2
 #define GEMCORESIMPRO2 0x08E60000 /* Does NOT match a real VID/PID as new firmware release exposes same VID/PID */
 #define GEMCOREPOSPRO 0x08E63479
 #define GEMALTOPROXDU 0x08E65503
@@ -238,6 +257,7 @@ typedef struct
 #define SCR331DINTTCOM	0x04E65120
 #define SDI010		0x04E65121
 #define SEC1210	0x04241202
+#define SEC1210URT 0x04241104
 #define CHERRYXX33	0x046A0005
 #define CHERRYST2000	0x046A003E
 #define OZ776		0x0B977762
