@@ -858,6 +858,60 @@ again:
 				else
 					usbDevice[reader_index].multislot_extension = NULL;
 
+
+#ifdef SEC1210_SYNC
+				if (SEC1210 == readerID)
+				{
+					usbDevice[reader_index].ccid.sec1210_interface = interface;
+
+					int other_interface_index = -1;
+					/* search the other interface */
+					for (unsigned int index=0; index<CCID_DRIVER_MAX_READERS ; index++)
+					{
+						/* ourself? */
+						if (index == reader_index)
+							continue;
+
+						/* empty slot */
+						if (! usbDevice[index].dev_handle)
+							continue;
+
+						if (bus_number == usbDevice[index].bus_number
+							&& device_address == usbDevice[index].device_address)
+						{
+							/* found it */
+							other_interface_index = index;
+							DEBUG_INFO2("found other interface at %d", index);
+							break;
+						}
+					}
+
+					if (other_interface_index >= 0)
+					{
+						DEBUG_INFO2("init SEC1210 2nd interface: %d",
+							interface);
+						/* point to the previous interface */
+						usbDevice[reader_index].ccid.sec1210_other_interface = &usbDevice[other_interface_index].ccid;
+						/* the previous interface points to us */
+						usbDevice[reader_index].ccid.sec1210_other_interface -> sec1210_other_interface = &usbDevice[reader_index].ccid;
+						/* share the cond struct */
+						usbDevice[reader_index].ccid.sec1210_shared = usbDevice[other_interface_index].ccid.sec1210_shared;
+					}
+					else
+					{
+						DEBUG_INFO2("init SEC1210 1st interface: %d",
+							interface);
+
+						/* init the cond struct */
+						struct _sec1210_cond *s = malloc(sizeof(struct _sec1210_cond));
+
+						pthread_cond_init(&s->sec1210_cond, NULL);
+						pthread_mutex_init(&s->sec1210_mutex, NULL);
+						usbDevice[reader_index].ccid.sec1210_shared = s;
+					}
+				}
+#endif
+
 				libusb_free_config_descriptor(config_desc);
 				goto end;
 			}
@@ -1167,6 +1221,26 @@ status_t CloseUSB(unsigned int reader_index)
 
 		pthread_mutex_destroy(&usbDevice[reader_index].polling_transfer_mutex);
 
+#ifdef SEC1210_SYNC
+		/* close the 2nd interface? */
+		_ccid_descriptor ccid_desc = usbDevice[reader_index].ccid;
+		DEBUG_INFO2("close interface: %d", ccid_desc.sec1210_interface);
+		if (ccid_desc.sec1210_other_interface)
+		{
+			/* the other interface is still present?
+			 * unregister ourself from it */
+			ccid_desc.sec1210_other_interface->sec1210_other_interface = NULL;
+		}
+		else
+		{
+			/* 2nd interface is closing */
+			/* Free the shared resources */
+			pthread_cond_destroy(&ccid_desc.sec1210_shared->sec1210_cond);
+			pthread_mutex_destroy(&ccid_desc.sec1210_shared->sec1210_mutex);
+			free(ccid_desc.sec1210_shared);
+		}
+#endif
+
 		if (usbDevice[reader_index].ccid.gemalto_firmware_features)
 			free(usbDevice[reader_index].ccid.gemalto_firmware_features);
 
@@ -1572,11 +1646,10 @@ int InterruptRead(int reader_index, int timeout /* in ms */)
 	if (NULL == transfer)
 		return LIBUSB_ERROR_NO_MEM;
 
-	libusb_fill_bulk_transfer(transfer,
+	libusb_fill_interrupt_transfer(transfer,
 		usbDevice[reader_index].dev_handle,
 		usbDevice[reader_index].interrupt, buffer, sizeof(buffer),
 		bulk_transfer_cb, &completed, timeout);
-	transfer->type = LIBUSB_TRANSFER_TYPE_INTERRUPT;
 
 	ret = libusb_submit_transfer(transfer);
 	if (ret < 0) {
@@ -1648,6 +1721,7 @@ int InterruptRead(int reader_index, int timeout /* in ms */)
 			break;
 
 		case LIBUSB_TRANSFER_TIMED_OUT:
+		case LIBUSB_TRANSFER_CANCELLED:
 			break;
 
 		default:
@@ -1726,14 +1800,13 @@ static void *Multi_PollingProc(void *p_ext)
 			usbDevice[msExt->reader_index].bus_number,
 			usbDevice[msExt->reader_index].device_address);
 
-		libusb_fill_bulk_transfer(transfer,
+		completed = 0;
+		libusb_fill_interrupt_transfer(transfer,
 			usbDevice[msExt->reader_index].dev_handle,
 			usbDevice[msExt->reader_index].interrupt,
 			buffer, CCID_INTERRUPT_SIZE,
 			bulk_transfer_cb, &completed, 0); /* No timeout ! */
 
-		transfer->type = LIBUSB_TRANSFER_TYPE_INTERRUPT;
-
 		rv = libusb_submit_transfer(transfer);
 		if (rv)
 		{
@@ -1746,7 +1819,6 @@ static void *Multi_PollingProc(void *p_ext)
 		usbDevice[msExt->reader_index].polling_transfer = transfer;
 		pthread_mutex_unlock(&usbDevice[msExt->reader_index].polling_transfer_mutex);
 
-		completed = 0;
 		while (!completed && !msExt->terminated)
 		{
 			rv = libusb_handle_events_completed(ctx, &completed);
