@@ -44,8 +44,10 @@
 
 /* disable asserts */
 #ifndef SIMCLIST_DEBUG
+#ifndef NDEBUG
 #define NDEBUG
 #endif
+#endif
 
 #include <assert.h>
 
@@ -166,7 +168,7 @@ typedef INT64   int64_t;
 #include "simclist.h"
 
 
-/* minumum number of elements for sorting with quicksort instead of insertion */
+/* minimum number of elements for sorting with quicksort instead of insertion */
 #define SIMCLIST_MINQUICKSORTELS        24
 
 
@@ -659,7 +661,7 @@ int list_clear(list_t *restrict l) {
 
     if (l->head_sentinel && l->tail_sentinel) {
         if (l->attrs.copy_data) {        /* also free user data */
-            /* spare a loop conditional with two loops: spareing elems and freeing elems */
+            /* spare a loop conditional with two loops: sparing elems and freeing elems */
             for (s = l->head_sentinel->next; l->spareelsnum < SIMCLIST_MAX_SPARE_ELEMS && s != l->tail_sentinel; s = s->next) {
                 /* move elements as spares as long as there is room */
                 if (s->data != NULL) free(s->data);
@@ -674,7 +676,7 @@ int list_clear(list_t *restrict l) {
             l->head_sentinel->next = l->tail_sentinel;
             l->tail_sentinel->prev = l->head_sentinel;
         } else { /* only free element containers */
-            /* spare a loop conditional with two loops: spareing elems and freeing elems */
+            /* spare a loop conditional with two loops: sparing elems and freeing elems */
             for (s = l->head_sentinel->next; l->spareelsnum < SIMCLIST_MAX_SPARE_ELEMS && s != l->tail_sentinel; s = s->next) {
                 /* move elements as spares as long as there is room */
                 l->spareels[l->spareelsnum++] = s;
@@ -1222,7 +1224,7 @@ int list_dump_filedescriptor(const list_t *restrict l, int fd, size_t *restrict
                     /* speculation confirmed */
                     WRITE_ERRCHECK(fd, ser_buf, bufsize);
                 } else {                        /* speculation found broken */
-                    WRITE_ERRCHECK(fd, & bufsize, sizeof(size_t));
+                    WRITE_ERRCHECK(fd, &bufsize, sizeof(bufsize));
                     WRITE_ERRCHECK(fd, ser_buf, bufsize);
                 }
                 free(ser_buf);
@@ -1245,7 +1247,7 @@ int list_dump_filedescriptor(const list_t *restrict l, int fd, size_t *restrict
                     }
                     WRITE_ERRCHECK(fd, x->data, bufsize);
                 } else {
-                    WRITE_ERRCHECK(fd, &bufsize, sizeof(size_t));
+                    WRITE_ERRCHECK(fd, &bufsize, sizeof(bufsize));
                     WRITE_ERRCHECK(fd, x->data, bufsize);
                 }
             }
@@ -1337,7 +1339,7 @@ int list_restore_filedescriptor(list_t *restrict l, int fd, size_t *restrict len
             if (NULL == buf)
                 return -1;
             for (cnt = 0; cnt < header.numels; cnt++) {
-                READ_ERRCHECK(fd, buf, header.elemlen);
+                READ_ERRCHECK(fd, buf, (ssize_t) header.elemlen);
                 list_append(l, l->attrs.unserializer(buf, & elsize));
                 totmemorylen += elsize;
             }
@@ -1347,7 +1349,7 @@ int list_restore_filedescriptor(list_t *restrict l, int fd, size_t *restrict len
                 buf = malloc(header.elemlen);
                 if (NULL == buf)
                     return -1;
-                READ_ERRCHECK(fd, buf, header.elemlen);
+                READ_ERRCHECK(fd, buf, (ssize_t) header.elemlen);
                 list_append(l, buf);
             }
             totmemorylen = header.numels * header.elemlen;
@@ -1362,7 +1364,7 @@ int list_restore_filedescriptor(list_t *restrict l, int fd, size_t *restrict len
                 buf = malloc((size_t)elsize);
                 if (NULL == buf)
                     return -1;
-                READ_ERRCHECK(fd, buf, elsize);
+                READ_ERRCHECK(fd, buf, (ssize_t) elsize);
                 totreadlen += elsize;
                 list_append(l, l->attrs.unserializer(buf, & elsize));
                 totmemorylen += elsize;
@@ -1374,7 +1376,7 @@ int list_restore_filedescriptor(list_t *restrict l, int fd, size_t *restrict len
                 buf = malloc(elsize);
                 if (NULL == buf)
                     return -1;
-                READ_ERRCHECK(fd, buf, elsize);
+                READ_ERRCHECK(fd, buf, (ssize_t) elsize);
                 totreadlen += elsize;
                 list_append(l, buf);
             }
